'use client'

import React from 'react';
import { motion } from 'framer-motion';
import { Facebook, Twitter, Instagram, Linkedin } from 'lucide-react';
import PaymentFooterSection from '@/components/ui/payment-footer-section';
import FloatingIconSection from '@/components/ui/floating-icon-section';

const Footer: React.FC = () => {
  const currentYear = new Date().getFullYear()

  return (
    <div>
      <footer className="fts-footer bg-gray-900 text-white py-12">
        <div className="fts-container max-w-6xl mx-auto px-4">
          <div className="fts-grid grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
            <motion.div 
              className="fts-about"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5 }}
            >
              <h3 className="fts-title text-xl font-bold mb-4">About Us</h3>
              <p className="fts-description text-gray-400">
                Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus lacinia odio vitae vestibulum.
              </p>
            </motion.div>

            <motion.div 
              className="fts-links"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5, delay: 0.1 }}
            >
              <h3 className="fts-title text-xl font-bold mb-4">Useful Links</h3>
              <ul className="fts-link-list space-y-2">
                {['Home', 'About Us', 'Services', 'Contact', 'Privacy Policy'].map((link, index) => (
                  <li key={index}>
                    <motion.a 
                      href={`#${link.toLowerCase().replace(' ', '-')}`}
                      className="fts-link text-gray-400 hover:text-white transition-colors duration-300"
                      whileHover={{ x: 5 }}
                      whileFocus={{ x: 5 }}
                    >
                      {link}
                    </motion.a>
                  </li>
                ))}
              </ul>
            </motion.div>

            <motion.div 
              className="fts-contact"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5, delay: 0.2 }}
            >
              <h3 className="fts-title text-xl font-bold mb-4">Contact Info</h3>
              <p className="fts-phone text-gray-400 mb-2">Phone: +123 456 7890</p>
              <p className="fts-email text-gray-400 mb-2">Email: info@example.com</p>
              <p className="fts-address text-gray-400">Address: 1234 Street Name, City, Country</p>
            </motion.div>

            <motion.div 
              className="fts-social"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5, delay: 0.3 }}
            >
              <h3 className="fts-title text-xl font-bold mb-4">Follow Us</h3>
              <div className="fts-social-icons flex space-x-4">
                {[Facebook, Twitter, Instagram, Linkedin].map((Icon, index) => (
                  <motion.a
                    key={index}
                    href="#"
                    className="fts-social-link text-gray-400 hover:text-white transition-colors duration-300"
                    whileHover={{ scale: 1.2 }}
                    whileFocus={{ scale: 1.2 }}
                  >
                    <Icon size={24} />
                  </motion.a>
                ))}
              </div>
            </motion.div>
          </div>

          <motion.hr 
            className="fts-divider border-gray-700 my-8"
            initial={{ scaleX: 0 }}
            whileInView={{ scaleX: 1 }}
            viewport={{ once: true }}
            transition={{ duration: 0.5 }}
          />

          <PaymentFooterSection/>
        </div>
      </footer>
      <FloatingIconSection />
    </div>
  )
}

export default Footer
